@@ -17,6 +17,27 @@ from obspy import UTCDateTime
 import pandas as pd
 from obspy.geodetics import gps2dist_azimuth
 import logging
+import pickle
+
+def init_logger(log_file,file_level=logging.DEBUG,stream_level=logging.INFO):
+    '''
+    Parameters:
+        log_file: file to save the log information
+        file_level: level for file writing
+        stream_level: level for stream writing
+    '''
+    logger = logging.getLogger()
+    logger.setLevel(logging.DEBUG)
+    fh = logging.FileHandler(log_file,mode='w')
+    fh.setLevel(logging.DEBUG)
+    formatter = logging.Formatter('%(asctime)s-%(filename)s-%(levelname)s: %(message)s')
+    fh.setFormatter(formatter)
+    ch = logging.StreamHandler()
+    ch.setLevel(logging.INFO)
+    ch.setFormatter(formatter)
+    logger.addHandler(ch)
+    logger.addHandler(fh)
+
 
 def extract_set_info(pth,sta_file,depth=2):
     """
@@ -34,6 +55,12 @@ def extract_set_info(pth,sta_file,depth=2):
     """
     logger = logging.getLogger()
     logger.info("Extract_set_info program launched...")
+    if os.path.exists(os.path.join(pth,'setinfo.pkl')):
+        f = open(os.path.join(pth,'setinfo.pkl'),'rb')
+        setinfo = pickle.load(f)
+        logger.info("Read in the existed setinfo.pkl and return")
+        return setinfo
+
     setinfo = {}
     sta_dict = load_sta(sta_file)
     s_times = []
@@ -90,6 +117,9 @@ def extract_set_info(pth,sta_file,depth=2):
     setinfo["netstas"] = netstas
     setinfo["center"] = [np.mean(stalons),np.mean(stalats)]
     logging.info("extract set info programme done")
+    f = open(os.path.join(pth,"setinfo.pkl"),'wb')
+    pickle.dump(setinfo,f)
+    f.close()
     return setinfo
 
 def load_sta(sta_file):
